@@ -15,6 +15,7 @@ from .core import (
     component_interactive,
     create_context,
     display,
+    get_context,
     get_widget,
     make,
     provide_context,
@@ -41,6 +42,7 @@ __all__ = [
     "make",
     "display",
     "get_widget",
+    "get_context",
     "use_context",
     "create_context",
     "use_exception",
